.. image:: https://img.shields.io/pypi/v/skeleton.svg
   :target: https://pypi.org/project/skeleton

.. image:: https://img.shields.io/pypi/pyversions/skeleton.svg

.. image:: https://img.shields.io/travis/jaraco/skeleton/master.svg
   :target: http://travis-ci.org/jaraco/skeleton

.. image:: https://readthedocs.org/projects/skeleton/badge/?version=latest
   :target: http://skeleton.readthedocs.io/en/latest/?badge=latest
